@@ -8,6 +8,7 @@ Main module to create x-alarms defined at the top level.
 
 import re
 
+from compose_x_common.compose_x_common import keyisset
 from troposphere import (
     AWS_REGION,
     AWS_STACK_ID,
@@ -22,7 +23,7 @@ from troposphere.cloudwatch import Alarm as CWAlarm
 from troposphere.cloudwatch import CompositeAlarm
 
 from ecs_composex.alarms.alarms_params import RES_KEY
-from ecs_composex.common import LOG, build_template, keyisset
+from ecs_composex.common import LOG, build_template
 from ecs_composex.common.compose_resources import XResource, set_resources
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.resources_import import import_record_properties
@@ -184,11 +185,13 @@ class Alarm(XResource):
 
     topics_key = "Topics"
 
-    def __init__(self, name, definition, module_name, settings):
+    def __init__(self, name, definition, module_name, settings, mapping_key=None):
         self.topics = []
         self.is_composite = False
         self.in_composite = False
-        super().__init__(name, definition, module_name, settings)
+        super().__init__(
+            name, definition, module_name, settings, mapping_key=mapping_key
+        )
         self.topics = (
             definition[self.topics_key]
             if keyisset(self.topics_key, self.definition)
