@@ -10,6 +10,7 @@ import re
 from copy import deepcopy
 from json import dumps
 
+from compose_x_common.compose_x_common import keyisset, keypresent
 from troposphere import (
     AWS_NO_VALUE,
     AWS_STACK_NAME,
@@ -52,14 +53,7 @@ from ecs_composex.cognito_userpool.cognito_params import (
     USERPOOL_DOMAIN,
     USERPOOL_ID,
 )
-from ecs_composex.common import (
-    LOG,
-    NONALPHANUM,
-    add_parameters,
-    build_template,
-    keyisset,
-    keypresent,
-)
+from ecs_composex.common import LOG, NONALPHANUM, add_parameters, build_template
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME, Parameter
 from ecs_composex.common.compose_resources import XResource, set_resources
 from ecs_composex.common.outputs import ComposeXOutput
@@ -810,7 +804,7 @@ class Elbv2(XResource):
 
     subnets_param = APP_SUBNETS
 
-    def __init__(self, name, definition, module_name, settings):
+    def __init__(self, name, definition, module_name, settings, mapping_key=None):
         if not keyisset("Listeners", definition):
             raise KeyError("You must specify at least one Listener for a LB.", name)
         self.lb_is_public = False
@@ -821,7 +815,9 @@ class Elbv2(XResource):
         self.unique_service_lb = False
         self.lb = None
         self.listeners = []
-        super().__init__(name, definition, module_name, settings)
+        super().__init__(
+            name, definition, module_name, settings, mapping_key=mapping_key
+        )
         self.validate_services()
         self.sort_props()
 
