@@ -4,12 +4,12 @@
 
 
 import re
-from troposphere import Sub, Ref, Join
+
+from troposphere import Join, Ref, Sub
 from troposphere.iam import Role
 
 from ecs_composex.common import LOG
 
-
 ROLE_ARN_ARG = "RoleArn"
 
 
