@@ -13,8 +13,9 @@ You can change the names *values* so you like so long as you keep it Alphanumeri
 """
 
 from os import path
-from ecs_composex.ecs_composex import X_KEY
+
 from ecs_composex.common.cfn_params import Parameter
+from ecs_composex.common.ecs_composex import X_KEY
 from ecs_composex.vpc.vpc_params import SG_ID_TYPE
 
 MOD_KEY = path.basename(path.dirname(path.abspath(__file__)))
